OC.L10N.register(
    "settings",
    {
    "Private" : "Privát",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Csak a mobilos Beszélgetés alkalmazáson keresztüli telefonszám integrációval egyeztetett emberek láthatják",
    "Local" : "Helyi",
    "Only visible to people on this instance and guests" : "Csak az ezen a példányon lévő személyek és a vendégek láthatják",
    "Federated" : "Föderált",
    "Only synchronize to trusted servers" : "Szinkronizálás csak a megbízható kiszolgálókkal",
    "Published" : "Közzétett",
    "Synchronize to trusted servers and the global and public address book" : "Szinkronizálás a megbízható kiszolgálókkal, valamint a globális és nyilvános címjegyzékkel",
    "Verify" : "Ellenőrzés",
    "Verifying …" : "Ellenőrzés…",
    "Unable to change password" : "Nem sikerült megváltoztatni a jelszót",
    "Very weak password" : "Nagyon gyenge jelszó",
    "Weak password" : "Gyenge jelszó",
    "So-so password" : "Nem túl jó jelszó",
    "Good password" : "Jó jelszó",
    "Strong password" : "Erős jelszó",
    "Groups" : "Csoportok",
    "Group list is empty" : "A csoportlista üres",
    "Unable to retrieve the group list" : "A csoportlista betöltése sikertelen",
    "{actor} added you to group {group}" : "{actor} hozzá lett adva a {group} csoporthoz",
    "You added {user} to group {group}" : "Hozzáadta {user} felhasználót a(z) {group} csoporthoz",
    "{actor} added {user} to group {group}" : "{actor} hozzáadta {user} felhasználót a(z) {group} csoporthoz",
    "An administrator added you to group {group}" : "A rendszergazda hozzáadta a(z) {group} csoporthoz",
    "An administrator added {user} to group {group}" : "A rendszergazda hozzáadta {user} felhasználót a(z) {group} csoporthoz",
    "{actor} removed you from group {group}" : "{actor} el lett távolítva a(z) {group} csoportból",
    "You removed {user} from group {group}" : "Eltávolította {user} felhasználót a(z) {group} csoportból",
    "{actor} removed {user} from group {group}" : "{actor} eltávolította {user} felhasználót a(z) {group} csoportból",
    "An administrator removed you from group {group}" : "A rendszergazda eltávolította a(z) {group} csoportból",
    "An administrator removed {user} from group {group}" : "A rendszergazda eltávolította {user} felhasználót a(z) {group} csoportból",
    "Your <strong>group memberships</strong> were modified" : "A <strong>csoporttagsága</strong> megváltozott",
    "{actor} changed your password" : "{actor} módosította a jelszavát",
    "You changed your password" : "Módosította a jelszavát",
    "Your password was reset by an administrator" : "A jelszavát visszaállította egy rendszergazda",
    "Your password was reset" : "A jelszava visszaállítva",
    "{actor} changed your email address" : "{actor} megváltoztatta az e-mail-címét",
    "You changed your email address" : "Megváltoztatta az e-mail-címét",
    "Your email address was changed by an administrator" : "Az e-mail-címét megváltoztatta egy rendszergazda",
    "You created app password \"{token}\"" : "Létrehozta a(z) „{token}” alkalmazásjelszót",
    "An administrator created app password \"{token}\"" : "Egy rendszergazda létrehozta a(z) „{token}” alkalmazásjelszót",
    "You deleted app password \"{token}\"" : "Törölte a(z) „{token}” alkalmazásjelszót",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Átnevezted a(z) „{token}” alkalmazásjelszót erre: „{newToken}”",
    "You granted filesystem access to app password \"{token}\"" : "Fájlrendszer-hozzáférést adott a(z) „{token}” alkalmazásjelszónak",
    "You revoked filesystem access from app password \"{token}\"" : "Visszavonta a(z) „{token}” alkalmazásjelszó fájlrendszer-hozzáférését",
    "Security" : "Biztonság",
    "You successfully logged in using two-factor authentication (%1$s)" : "Sikeresen bejelentkezett kétfaktoros hitelesítés használatával (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Egy kétfaktoros hitelesítést használó bejelentkezési kísérlet sikertelen (%1$s)",
    "Remote wipe was started on %1$s" : "Távoli törlés indítva ezen: %1$s",
    "Remote wipe has finished on %1$s" : "Távol törlés befejezve ezen: %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "A <strong>jelszava </strong> vagy <strong>e-mail-címe</strong> megváltozott",
    "Could not remove app." : "Nem sikerült eltávolítani az alkalmazást.",
    "Could not update app." : "Nem sikerült frissíteni az alkalmazást.",
    "Wrong password" : "Hibás jelszó",
    "Unable to change personal password" : "Nem lehet megváltoztatni a személyes jelszót",
    "Saved" : "Mentve",
    "No user supplied" : "Nincs megadva felhasználó",
    "Unable to change password. Password too long." : "Nem lehet megváltoztatni a jelszót. A jelszó túl hosszú.",
    "Authentication error" : "Hitelesítései hiba",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Adjon meg egy rendszergazdai helyreállító jelszót; különben az összes felhasználó adata elvész.",
    "Wrong admin recovery password. Please check the password and try again." : "Hibás rendszergazdai helyreállítási jelszó. Ellenőrizze a jelszót és próbálja újra.",
    "Backend does not support password change, but the user's encryption key was updated." : "A háttérszolgáltatás nem támogatja a jelszómódosítást, de a felhasználó titkosítási kulcsa frissítve lett.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "alkalmazások telepítése és frissítése az alkalmazástár vagy a föderált felhőmegosztás segítségével",
    "Federated Cloud Sharing" : "Föderált felhőmegosztás",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "A cURL elavult %1$s verziót (%2$s) használ. Frissítse az operációs rendszert, vagy az egyes funkciók (mint például a %3$s) megbízhatatlanul fognak működni.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Nem sikerült megállapítani, hogy a cURL TLS-verziója elavult-e vagy sem, mert hiba történt a https://nextcloud.com felé küldött HTTPS-kérés során. További részletekért ellenőrizze a Nextcloud naplófájlját.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "A PHP OPcache modul nincs betöltve. A jobb teljesítmény érdekében javasoljuk, hogy töltse be a PHP telepítésébe.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "Az OPcache ki van kapcsolva. A jobb teljesítmény érdekében ajánlatos, hogy beállítsa az <code>opcache.enable=1</code> értéket a PHP konfigurációjába.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "Az OPcache úgy van beállítva, hogy eltávolítja a kódban lévő megjegyzéseket. Ha az OPcache be van kapcsolva, akkor be kell állítani az <code>opcache.save_comments=1</code> értéket, hogy a Nextcloud működjön.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "A Nextcloud számára nem engedélyezett az OPcache API használata. Ha be van kapcsolva az OPcache, akkor erősen ajánlott, hogy a Nexcloud összes könyvtára szerepeljen az <code>opcache.restrict_api</code> beállításban, vagy kapcsolja ki, hogy letiltsa az OPcache API korlátozásait, hogy megakadályozza a Nextcloud magjának vagy alkalmazásainak frissítése során fellépő hibákat.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "A Nextcloud számára nem engedélyezett az OPcache API használata. Erősen ajánlott, hogy a Nexcloud összes könyvtára szerepeljen az <code>opcache.restrict_api</code> beállításban, vagy kapcsolja ki, hogy letiltsa az OPcache API korlátozásait, hogy megakadályozza a Nextcloud magjának vagy alkalmazásainak frissítése során fellépő hibákat.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Majdnem túllépte az OPcache kulcsok legnagyobb számát. Hogy biztosítsa, hogy az összes parancsfájl tárolható legyen a gyorsítótárban, ajánlatos, hogy a(z) <code>%s</code> értéknél nagyobbra állítsa az <code>opcache.max_accelerated_files</code> beállítást a PHP konfigurációjában.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Az OPcache puffer majdnem megtelt. Hogy biztosítsa, hogy az összes parancsfájl tárolható legyen a gyorsítótárban, ajánlatos, hogy a(z) <code>%s</code> értéknél nagyobbra állítsa az <code>opcache.max_accelerated_files</code> beállítást a PHP konfigurációjában.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Az OPcache internalizált karakterláncokat tartalmazó puffere majdnem megtelt. Hogy biztosítsa, hogy az ismétlődő karakterláncok hatásosan gyorsítótárazhatók legyenek, ajánlatos, hogy a(z) <code>%s</code> értéknél nagyobbra állítsa az <code>opcache.interned_strings_buffer</code> beállítást a PHP konfigurációjában.",
    "Invalid SMTP password." : "Érvénytelen SMTP-jelszó.",
    "Email setting test" : "E-mail beállítás tesztelése",
    "Well done, %s!" : "Szép munka,  %s!",
    "If you received this email, the email configuration seems to be correct." : "Ha ezt a levelet látod, a beállításaid megfelelőnek tűnnek.",
    "Email could not be sent. Check your mail server log" : "Az e-mail nem küldhető el. Ellenőrizze a levelezőkiszolgáló naplójában.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hiba történt az e-mail küldésekor. Ellenőrizze a beállításokat. (Hiba: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Előbb meg kell adnia az e-mail-címét, mielőtt tesztelni tudná az e-mail küldést. Ehhez ugorjon ide: %s.",
    "Invalid user" : "Érvénytelen felhasználó",
    "Invalid mail address" : "Érvénytelen e-mail-cím",
    "Settings saved" : "Beállítások mentve",
    "Unable to change full name" : "Nem sikerült megváltoztatni a teljes nevét",
    "Unable to change email address" : "Nem sikerült megváltoztatni az e-mail-címet",
    "Unable to set invalid phone number" : "A telefonszám formátuma hibás",
    "Unable to set invalid website" : "Nem állítható be érvénytelen weboldal",
    "Some account data was invalid" : "A fiókadatok valamelyike érvénytelen",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "A Twitter-fiók megerősítéséhez tweetelje ki a következőt (pontosan így, sortörések nélkül tegye közzé):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "A weboldala ellenőrzése érdekében helyezze el a következő tartalmat a  „.well-known/CloudIdVerificationCode.txt” fájlba (figyeljen arra, hogy az egész szöveg egy sorban legyen):",
    "%1$s changed your password on %2$s." : "%1$s megváltoztatta a jelszavát ennél: %2$s.",
    "Your password on %s was changed." : "A jelszava megváltozott ennél: %s.",
    "Your password on %s was reset by an administrator." : "A jelszavát visszaállította egy rendszergazda ennél: %s.",
    "Your password on %s was reset." : "A jelszava visszaállítva ennél: %s. ",
    "Password for %1$s changed on %2$s" : "%1$s jelszava megváltozott ennél: %2$s.",
    "Password changed for %s" : "%s jelszava megváltozott",
    "If you did not request this, please contact an administrator." : "Ha ezt nem Ön kérte, lépjen kapcsolatba egy rendszergazdával.",
    "Your email address on %s was changed." : "Az e-mail-címe megváltozott ennél: %s.",
    "Your email address on %s was changed by an administrator." : "Az e-mail-címét megváltoztatta egy rendszergazda ennél: %s.",
    "Email address for %1$s changed on %2$s" : "%1$s e-mail-címe megváltozott ennél:%2$s",
    "Email address changed for %s" : "%s e-mail-címe megváltozott",
    "The new email address is %s" : "Az új e-mail-cím: %s",
    "Your %s account was created" : "Az Ön %s-fiókja létrehozva",
    "Welcome aboard" : "Üdvözöljük",
    "Welcome aboard %s" : "Kedves %s!",
    "Welcome to your %s account, you can add, protect, and share your data." : "Üdvözöljük a %s-fiókjában, itt biztonságosan tárolhatja és megoszthatja az adatait.",
    "Your username is: %s" : "A felhasználóneve: %s",
    "Set your password" : "Jelszó beállítása",
    "Go to %s" : "Ugrás ide: %s",
    "Install Client" : "Kliens telepítése",
    "Logged in user must be a subadmin" : "Nem rendszergazda felhasználóként kell bejelentkezzen",
    "Apps" : "Alkalmazások",
    "Settings" : "Beállítások",
    "Personal" : "Személyes",
    "Administration" : "Adminisztráció",
    "Additional settings" : "További beállítások",
    "Administration privileges" : "Rendszergazdai jogosultságok",
    "Groupware" : "Csoportmunka",
    "Overview" : "Áttekintés",
    "Basic settings" : "Alapvető beállítások",
    "Sharing" : "Megosztás",
    "Availability" : "Elérhetőség",
    "Personal info" : "Személyes információk",
    "Mobile & desktop" : "Mobil és asztali",
    "Email server" : "E-mail kiszolgáló",
    "Security & setup warnings" : "Biztonsági és telepítési figyelmeztetések",
    "Background jobs" : "Háttérfeladatok",
    "Create" : "Létrehozás",
    "Change" : "Módosítás",
    "Delete" : "Törlés",
    "Reshare" : "Megosztás újra",
    "Unlimited" : "Korlátlan",
    "Verifying" : "Ellenőrzés",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Függőben van egy háttérfolyamat, amely ellenőrzi a felhasználó által importált SSL-tanúsítványokat. Kérjük, nézzen vissza később. ",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Vannak olyan felhasználók által importált SSL-tanúsítványok, melyeket a Nextcloud 21 már nem használ. Importálhatók parancssorból az „occ security: certificate: import” paranccsal. Az adatkönyvtárban található elérési utak az alábbiakban láthatók.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Felhasználók vagy csoportok érvénytelen UUID azonosítói találhatók. Nézze át a „UUID észlelés felülbírálása” beállítást az LDAP beállítások Szakértő részében, majd a frissítésükhöz használja az „occ ldap:update-uuid” parancsot.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "A régi kiszolgálóoldali titkosítási formátum engedélyezett. Javasoljuk ennek letiltását.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "A MariaDB következő verziója van használatban: „%s”. A Nextcloud 21 és az újabb verziók már nem támogatják ezt a verziót, legalább a MariaDB 10.2-es verziója szükséges.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "A MySQL következő verziója van használatban: „%s”. A Nextcloud 21 és az újabb verziók már nem támogatják ezt a verziót, legalább a MySQL 8.0-s vagy a MariaDB 10.2-es verziója szükséges.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "A PostgreSQL következő verziója van használatban: „%s”. A Nextcloud 21 és az újabb verziók már nem támogatják ezt a verziót, legalább a PostgreSQL 9.6-os verziója szükséges.",
    "Profile information" : "Profilinformációk",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilkép, teljes név, e-mail-cím, telefonszám, cím, weboldal, Twitter-fiók, szervezet, szerepkör, fejléc, életrajz és hogy engedélyezett-e",
    "Nextcloud settings" : "Nextcloud beállítások",
    "Here you can decide which group can access certain sections of the administration settings." : "Itt eldöntheti, hogy mely csoportok érhetik el a rendszergazdai beállítások bizonyos szakaszait.",
    "None" : "Egyik sem",
    "Unable to modify setting" : "A beállítás nem módosítható",
    "Two-Factor Authentication" : "Kétfaktoros hitelesítés",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "A kétfaktoros hitelesítés az összes felhasználó vagy adott csoport tagjai esetén követelhető meg. Ha nincs nekik kétfaktoros szolgáltató beállítva, akkor nem fognak tudni bejelentkezni a rendszerbe.",
    "Enforce two-factor authentication" : "Kétfaktoros hitelesítés megkövetelése",
    "Limit to groups" : "Csoportokra korlátozás",
    "Enforcement of two-factor authentication can be set for certain groups only." : "A kétfaktoros hitelesítés megkövetelése csak bizonyos csoportokra állítható be.",
    "Two-factor authentication is enforced for all members of the following groups." : "A kétfaktoros hitelesítés az alábbi csoportok számára kötelező.",
    "Enforced groups" : "Kötelezett csoportok",
    "Two-factor authentication is not enforced for members of the following groups." : "A kétfaktoros hitelesítés az alábbi csoportok számára nem kötelező.",
    "Excluded groups" : "Kizárt csoportok",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Amikor csoportok ki vannak választva/zárva, akkor az alábbi logika határozza meg, hogy egy felhasználó esetén kötelező-e a kétfaktoros hitelesítés: ha nincs csoport kiválasztva, akkor a kétfaktoros hitelesítés mindenkinél be van kapcsolva, kivéve a kizárt csoportok tagjainál. Ha van kiválasztva csoport, akkor a kétfaktoros hitelesítés számukra kötelező. Amennyiben egy felhasználó kiválasztott és kizárt csoportban is szerepel, akkor a kiválasztás lesz az erősebb, így a kétfaktoros hitelesítés neki is kötelező.",
    "Save changes" : "Változások mentése",
    "All" : "Mind",
    "Limit app usage to groups" : "Alkalmazás használatának csoportokra korlátozása",
    "No results" : "Nincs találat",
    "Update to {version}" : "Frissítés erre: {version}",
    "Remove" : "Eltávolítás",
    "Disable" : "Letiltás",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ennek az alkalmazásnak nincs minimum szükséges Nextcloud verziója megadva. Ez hiba lesz a jövőben.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ennek az alkalmazásnak nincs maximum szükséges Nextcloud verziója megadva. Ez hiba lesz a jövőben.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ezt az alkalmazást nem lehet telepíteni, mert a következő függőségek hiányoznak:",
    "View in store" : "Megtekintés a tárban",
    "Visit website" : "Weboldal meglátogatása",
    "Report a bug" : "Hiba bejelentése",
    "User documentation" : "Felhasználói dokumentáció",
    "Admin documentation" : "Rendszergazdai dokumentáció",
    "Developer documentation" : "Fejlesztői dokumentáció",
    "This app is supported via your current Nextcloud subscription." : "Az alkalmazás támogatását a jelenlegi Nextcloud előfizetése biztosítja.",
    "Supported" : "Támogatott",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "A kiemelt alkalmazásokat a közösség tagjai készítik. Ezek biztosítják a fő funkciókat, és készek az éles használatra.",
    "Featured" : "Kiemelt",
    "Update to {update}" : "Frissítés erre: {update}",
    "All apps are up-to-date." : "Minden alkalmazás naprakész.",
    "Results from other categories" : "Találatok más kategóriákból",
    "No apps found for your version" : "Nem található alkalmazás a verziójához",
    "Disable all" : "Összes tiltása",
    "Enable all" : "Összes engedélyezése",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n alkalmazás frissítése érhető el","%n alkalmazás frissítése érhető el"],
    "_Update_::_Update all_" : ["Frissítés","Összes frissítése"],
    "Marked for remote wipe" : "Távoli törlésre jelölve",
    "Device settings" : "Eszközbeállítások",
    "Allow filesystem access" : "Fájlrendszer hozzáférés engedélyezése",
    "Rename" : "Átnevezés",
    "Revoke" : "Visszavonás",
    "Wipe device" : "Eszköz törlése",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "A token visszavonása lehet hogy meggátolja az eszköz törlését, ha az még nem kezdődött el.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS-es alkalmazás",
    "{productName} Android app" : "{productName} androidos alkalmazás",
    "{productName} Talk for iOS" : "{productName} Beszélgetés iOS-re",
    "{productName} Talk for Android" : "{productName} Beszélgetés Androidra",
    "Sync client - {os}" : "Szinkronizálási kliens – {os}",
    "This session" : "Ez a munkamenet",
    "Device" : "Eszköz",
    "Last activity" : "Utolsó tevékenység",
    "Devices & sessions" : "Eszközök és munkamenetek",
    "Web, desktop and mobile clients currently logged in to your account." : "A fiókjába jelenleg bejelentkezett webes, asztali és mobilkliensek.",
    "Do you really want to wipe your data from this device?" : "Valóban törölni szeretné az adatokat erről az eszközről?",
    "Confirm wipe" : "Törlés megerősítése",
    "Error while creating device token" : "Hiba az eszköztoken létrehozása során",
    "Error while updating device token scope" : "Hiba az eszköztoken hatókörének frissítése során",
    "Error while updating device token name" : "Hiba az eszköztoken nevének frissítése során",
    "Error while deleting the token" : "Hiba az eszköztoken törlése során",
    "Error while wiping the device with the token" : "Hiba a tokennel rendelkező eszköz törlése során",
    "App name" : "Alkalmazásnév",
    "Create new app password" : "Új alkalmazásjelszó létrehozása",
    "Use the credentials below to configure your app or device." : "Használja a lenti hitelesítő adatokat, hogy beállítsa az alkalmazását vagy eszközét.",
    "For security reasons this password will only be shown once." : "Biztonsági okokból ez a jelszó csak egyszer jelenik meg.",
    "Username" : "Felhasználónév",
    "Password" : "Jelszó",
    "Done" : "Kész",
    "Show QR code for mobile apps" : "A mobilalkalmazások QR-kódjának megjelenítése",
    "Copied!" : "Másolva!",
    "Copy" : "Másolás",
    "Could not copy app password. Please copy it manually." : "Nem lehet az alkalmazásjelszót másolni. Másolja át kézileg.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "A kiszolgáló helyes működéséhez fontos, hogy a háttérfeladatok megfelelően legyenek beállítva. A Cron beállítás javasolt. További részletekért lásd a dokumentációt.",
    "Last job execution ran {time}. Something seems wrong." : "Utolsó feladatfuttatás:%s. Valami nincs rendben.",
    "Last job ran {relativeTime}." : "Utolsó feladatfuttatás: {relativeTime}.",
    "Background job did not run yet!" : "A háttérfeladat még nem futott le!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Egy feladat végrehajtása minden egyes oldalbetöltésnél. Használati eset: egyfelhasználós példány",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "A cron.php egy webcron szolgáltatásnál van regisztrálva, hogy 5 percenkenként meghívja a cron.php-t. Használati eset: Nagyon kis példány (1-5 felhasználó, használattól függően).",
    "Cron (Recommended)" : "Cron (ajánlott)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Ennek futtatásához a PHP POSIX kiterjesztés szükséges. A részletekért lásd a {linkstart}PHP dokumentációt{linkend}.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "A rendszer cron szolgáltatásának használata a cron.php fájl 5 percenként meghívásához. Az összes példány esetén ez javasolt.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "A cron.php-t „{user}” rendszerfelhasználónak kell végrehajtania.",
    "Unable to update background job mode" : "A háttérfeladat módja nem frissíthető",
    "Profile" : "Profil",
    "Enable or disable profile by default for new users." : "A profil alapértelmezett engedélyezése vagy letiltása az új felhasználók számára.",
    "Enable" : "Engedélyezés",
    "Unable to update profile default setting" : "A profil alapértelmezett beállítása nem frissíthető",
    "Server-side encryption" : "Kiszolgálóoldali titkosítás",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "A kiszolgálóoldali titkosítás segítségével a tárolt fájlok titkosítva lesznek tárolva a kiszolgálón. Ez korlátozásokkal jár, például teljesítménycsökkenést okoz, így csak akkor kapcsolja be, ha szükséges.",
    "Enable server-side encryption" : "Kiszolgálóoldali titkosítás engedélyezése",
    "Please read carefully before activating server-side encryption:" : "Olvassa el figyelmesen, mielőtt bekapcsolja a kiszolgálóoldali titkosítást:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ha egyszer engedélyezve lett a titkosítás, akkor onnantól kezdve a kiszolgálón lévő összes fájl titkosításra kerül, melyet később csak akkor lehet visszafordítani, ha azt az aktív titkosítási modul támogatja, és minden előkövetelmény (például lett helyreállítási kulcs beállítva) teljesül.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "A titkosítás önmagában nem garantálja a rendszer biztonságát. Olvassa el a dokumentációt, hogy további információkat szerezzen a titkosítási alkalmazás működéséről, és a támogatott lehetőségekről.",
    "Be aware that encryption always increases the file size." : "Ügyeljen arra, hogy a titkosítás mindig megnöveli a fájlok méretét.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Mindig jó ötlet rendszeres biztonsági mentést készíteni az adatokról. Titkosítás esetén győződjön meg arról, hogy a titkosítási kulcsokról is készít biztonsági mentést.",
    "This is the final warning: Do you really want to enable encryption?" : "Ez az utolsó figyelmeztetés: Biztos, hogy engedélyezi a titkosítást?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nincs titkosítási modul betöltve, engedélyezze a titkosítási modult az alkalmazások menüben.",
    "Select default encryption module:" : "Alapértelmezett titkosítási modul kiválasztása:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Át kell költöztetni a titkosítási kulcsokat a régi titkosításból (ownCloud <= 8.0) az újba. Engedélyezze az „Alapértelmezett titkosítási modult” és futtassa ezt: {command}",
    "Unable to update server side encryption config" : "A kiszolgálóoldali titkosítás beállításai nem frissíthetők",
    "Rename group" : "Csoport átnevezése",
    "Remove group" : "Csoport eltávolítása",
    "You are about to remove the group {group}. The users will NOT be deleted." : "A(z) {group} csoport eltávolítására készül. A felhasználók NEM lesznek törölve.",
    "Please confirm the group removal " : "Erősítse meg a csoport eltávolítását",
    "Current password" : "Jelenlegi jelszó",
    "New password" : "Új jelszó",
    "Change password" : "Jelszó megváltoztatása",
    "Your profile picture" : "Az Ön profilképe",
    "Upload profile picture" : "Profilkép feltöltése",
    "Choose profile picture from files" : "Válasszon profilképet a fájlok közül",
    "Remove profile picture" : "Profilkép eltávolítása",
    "png or jpg, max. 20 MB" : "png vagy jpg, legfeljebb 20 MB",
    "Picture provided by original account" : "Az eredeti fiók által biztosított kép.",
    "Cancel" : "Mégse",
    "Set as profile picture" : "Beállítás profilképként",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Vegye figyelembe, hogy akár 24 óráig is eltarthat, amíg a profilkép mindenhol frissül.",
    "Choose your profile picture" : "Válassza ki a profilképét",
    "Please select a valid png or jpg file" : "Válasszon egy érvényes PNG- vagy JPG-fájlt",
    "Error setting profile picture" : "Hiba a profilkép beállítása során",
    "Error cropping profile picture" : "Hiba a profilkép levágása során",
    "Error saving profile picture" : "Hiba a profilkép mentése során",
    "Error removing profile picture" : "Hiba a profilkép eltávolítása során",
    "Your biography" : "Az Ön életrajza",
    "Details" : "Részletek",
    "You are a member of the following groups:" : "Ön a következő csoportok tagja:",
    "You are using <strong>{usage}</strong>" : "Ezt használja: <strong>{usage}</strong>",
    "Your full name" : "Az Ön teljes neve",
    "Email options" : "E-mail beállítások",
    "Primary email for password reset and notifications" : "Elsődleges e-mail-cím a jelszó-visszaállításhoz és az értesítésekhez",
    "Remove primary email" : "Elsődleges e-mail-cím eltávolítása",
    "Delete email" : "E-mail-cím törlése",
    "Unset as primary email" : "Elsődleges e-mail-cím eltávolítása",
    "This address is not confirmed" : "Ez a cím nincs megerősítve",
    "Set as primary email" : "Beállítás elsődleges e-mail-címként",
    "Your email address" : "Az Ön e-mail-címe",
    "Additional email address {index}" : "{index}. további e-mail-cím",
    "Unable to delete primary email address" : "Az elsődleges e-mail-cím nem törölhető",
    "Unable to update primary email address" : "Az elsődleges e-mail-cím nem frissíthető",
    "Unable to add additional email address" : "További e-mail-cím nem adható hozzá",
    "Unable to update additional email address" : "A további e-mail-cím nem frissíthető",
    "Unable to delete additional email address" : "A további e-mail-cím nem törölhető",
    "No email address set" : "Nincs e-mail-cím beállítva",
    "Additional emails" : "További e-mail-címek",
    "Your headline" : "Az Ön címsora",
    "Language" : "Nyelv",
    "Help translate" : "Segítsen a fordításban",
    "Unable to update language" : "A nyelv nem frissíthető",
    "No language set" : "Nyelv nincs beállítva",
    "Locale" : "Területi beállítás",
    "Your location" : "A saját helye",
    "Your organisation" : "Az Ön szervezete",
    "Your phone number" : "Telefonszáma",
    "Edit your Profile visibility" : "Profil láthatósága",
    "Enable Profile" : "Profil engedélyezése",
    "Unable to update profile enabled state" : "A profil engedélyezési állapota nem frissíthető",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "A profiljában a láthatóság vagy hatókör közül a szigorúbb beállítás lesz figyelembe véve. Például ha a láthatóság „Mindenki számára látható” és a hatókör „Privát”, akkor a „Privát” lesz figyelembe véve.",
    "{displayId}" : "{displayId}",
    "Unable to update visibility of {displayId}" : "A(z) {displayId} láthatósága nem frissíthető",
    "Your role" : "Az Ön szerepköre",
    "Your Twitter handle" : "A Twitter-azonosítója",
    "Your website" : "A saját weboldala",
    "No {property} set" : "Nincs {property} beállítva",
    "Unable to update {property}" : "A(z) {property} nem frissíthető",
    "Change scope level of {property}, current scope is {scope}" : "A(z) {property} hatókörszintjének módosítása, a jelenlegi hatókör: {scope}",
    "Unable to update federation scope of the primary {property}" : "Az elsődleges {property} föderációs hatóköre nem frissíthető",
    "Unable to update federation scope of additional {property}" : "A további {property} föderációs hatóköre nem frissíthető",
    "Add additional email" : "További e-mail hozzáadása",
    "Add" : "Hozzáadás",
    "You do not have permissions to see the details of this user" : "Nincs jogosultsága megnézni a felhasználó részletes adatait",
    "Add new password" : "Új jelszó hozzáadása",
    "Add new email address" : "Új e-mail-cím hozzáadása",
    "Add user to group" : "Felhasználó hozzáadása egy csoporthoz",
    "Set user as admin for" : "Felhasználó beállítása rendszergazdaként itt:",
    "Select user quota" : "Válasszon felhasználói kvótát",
    "Delete user" : "Felhasználó törlése",
    "Wipe all devices" : "Összes eszköz törlése",
    "Disable user" : "Felhasználó tiltása",
    "Enable user" : "Felhasználó engedélyezése",
    "Resend welcome email" : "Üdvözlő üzenet ismételt elküldése",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Az eszköz elvesztése vagy a szervezetből való kilépés esetén ez távolról képes eltávolítani {userid} minden nextcloudos adatát a hozzá köthető eszközökről: {userid}. Csak akkor működik, ha az eszközök kapcsolódnak az internethez.",
    "Remote wipe of devices" : "Eszközök távoli törlése",
    "Wipe {userid}'s devices" : "{userid} eszközeinek törlése",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "{userid} fiókjának teljes törlése, beleértve a személyes fájljait, alkalmazásadatait, stb.",
    "Account deletion" : "Fiók törlése",
    "Delete {userid}'s account" : "{userid} fiókjának törlése",
    "Welcome mail sent!" : "Üdvözlő üzenet elküldve!",
    "Edit User" : "Felhasználó szerkesztése",
    "Toggle user actions menu" : "Felhasználói műveletek menü be/ki",
    "{size} used" : "{size} felhasználva",
    "New user" : "Új felhasználó",
    "Will be autogenerated" : "Automatikusan lesz elkészítve",
    "Display name" : "Megjelenítendő név",
    "Email" : "E-mail",
    "Default language" : "Alapértelmezett nyelv",
    "Add a new user" : "Új felhasználó felvétele",
    "Group admin for" : "Csoport rendszergazda itt:",
    "Quota" : "Kvóta",
    "User backend" : "Felhasználói háttérszolgáltatás",
    "Storage location" : "Háttértár helye",
    "Last login" : "Utolsó bejelentkezés",
    "No users in here" : "Nincsenek felhasználók",
    "Default quota" : "Alapértelmezett kvóta",
    "Common languages" : "Alapvető nyelvek",
    "Other languages" : "Más nyelvek",
    "Password change is disabled because the master key is disabled" : "A jelszó megváltoztatása tiltott, mert a mesterkulcs tiltott",
    "Passwordless authentication requires a secure connection." : "A jelszó nélküli hitelesítés biztonságos kapcsolatot igényel.",
    "Add WebAuthn device" : "WebAuth eszköz hozzáadása",
    "Please authorize your WebAuthn device." : "Hitelesítse a WebAuthn eszközét.",
    "Name your device" : "Nevezze el az eszközét",
    "Adding your device …" : "Az eszköze hozzáadása…",
    "Server error while trying to add WebAuthn device" : "Kiszolgálóhiba a WebAuthn eszköz hozzáadása során",
    "Server error while trying to complete WebAuthn device registration" : "Kiszolgálóhiba a WebAuthn eszköz regisztrációjának befejezése során",
    "Unnamed device" : "Névtelen eszköz",
    "Passwordless Authentication" : "Jelszó nélküli hitelesítés",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Állítsa be a fiókját a a FIDO2 szabvány követő jelszó nélküli hitelesítéssel.",
    "No devices configured." : "Nincs eszköz beállítva.",
    "The following devices are configured for your account:" : "A következő eszközök vannak a fiókjához kapcsolva:",
    "Your browser does not support WebAuthn." : "A böngészője nem támogatja a WebAuthn szabványt.",
    "Your apps" : "Az Ön alkalmazásai",
    "Active apps" : "Aktív alkalmazások",
    "Disabled apps" : "Letiltott alkalmazások",
    "Updates" : "Frissítések",
    "App bundles" : "Alkalmazáscsomagok",
    "Featured apps" : "Kiemelt alkalmazások",
    "{license}-licensed" : "{license}-licencelt",
    "Changelog" : "Változásnapló",
    "by {author}\n{license}" : "szerző: {author}\n{license}",
    "Enter group name" : "Adja meg a csoport nevét",
    "Add group" : "Csoport hozzáadása",
    "Active users" : "Aktív felhasználók",
    "Admins" : "Rendszergazdák",
    "Disabled users" : "Letiltott felhasználók",
    "Default quota:" : "Alapértelmezett kvóta:",
    "Select default quota" : "Válasszon alapértelmezett kvótát",
    "Show Languages" : "Nyelvek megjelenítése",
    "Show last login" : "Utolsó bejelentkezés megjelenítése",
    "Show user backend" : "Felhasználói háttérszolgáltatás megjelenítése",
    "Show storage path" : "Tároló útvonal megjelenítése",
    "Send email to new user" : "E-mail küldése az új felhasználónak",
    "Not saved" : "Nincs mentve",
    "Sending…" : "Küldés…",
    "Email sent" : "E-mail elküldve",
    "Location" : "Hely",
    "Profile picture" : "Profilkép",
    "About" : "Névjegy",
    "Full name" : "Teljes név",
    "Additional email" : "További e-mail-cím",
    "Headline" : "Címsor",
    "Organisation" : "Szervezet",
    "Phone number" : "Telefonszám",
    "Role" : "Szerepkör",
    "Twitter" : "Twitter",
    "Website" : "Weboldal",
    "Profile visibility" : "Profil láthatósága",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Nem érhető el, mivel ez a tulajdonság szükséges a fő funkciókhoz, köztük a fájlmegosztáshoz és a naptármeghívásokhoz.",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nem érhető el, mert a felhasználóspecifikus adatok közzététele a lekérési kiszolgáló felé nem engedélyezett, ha kérdése van, lépjen kapcsolatba a rendszergazdával.",
    "Show to everyone" : "Mindenki számára látható",
    "Show to logged in users only" : "Csak a bejelentkezett felhasználók számára látható",
    "Hide" : "Elrejtés",
    "Download and enable" : "Letöltés és engedélyezés",
    "Enable untested app" : "Teszteletlen alkalmazás engedélyezése",
    "The app will be downloaded from the App Store" : "Az alkalmazás letöltésre kerül az alkalmazástárból",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ez az alkalmazás nincs megjelölve, hogy kompatibilis lenne a jelenlegi Nextcloud verzióval. Ha folytatja, telepítheti az alkalmazást. Azonban az alkalmazás lehet, hogy nem fog rendeltetés szerint működni.",
    "Never" : "Soha",
    "An error occurred during the request. Unable to proceed." : "Hiba történt a kérés során. Nem lehet folytatni.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Ez az alkalmazás engedélyezett, de frissíteni kell. 5 másodpercen belül a frissítési oldalra lesz irányítva.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Hiba: az alkalmazás nem nem engedélyezhető, mert instabillá tenné a kiszolgálót",
    "Administrator documentation" : "Rendszergazdai dokumentáció",
    "Documentation" : "Dokumentáció",
    "Forum" : "Fórum",
    "Login" : "Bejelentkezés",
    "Plain" : "Egyszerű",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Dokumentáció megnyitása",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Fontos, hogy a levelezés be legyen állítva a kiszolgálón, például a jelszó-visszaállítások és az értesítések miatt.",
    "Send mode" : "Küldési mód",
    "Encryption" : "Titkosítás",
    "Sendmail mode" : "Sendmail mód",
    "From address" : "Feladó címe",
    "Authentication method" : "Hitelesítési mód",
    "Authentication required" : "Hitelesítés szükséges",
    "Server address" : "Kiszolgáló címe",
    "Port" : "Port",
    "Credentials" : "Hitelesítő adatok",
    "SMTP Username" : "SMTP felhasználónév",
    "SMTP Password" : "SMTP jelszó",
    "Save" : "Mentés",
    "Test and verify email settings" : "E-mail beállítások tesztelése és ellenőrzése",
    "Send email" : "E-mail küldése",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "A példánya biztonságához és megfelelő teljesítményéhez fontos, hogy minden beállítás helyes legyen. Ennek érdekében segítünk pár automatikus ellenőrzéssel. További információkért nézze meg a kapcsolódó dokumentációt.",
    "All checks passed." : "Minden ellenőrzés sikeres.",
    "There are some errors regarding your setup." : "Probléma lépett fel a beállításaival kapcsolatban.",
    "There are some warnings regarding your setup." : "Figyelmeztetések találhatók a beállításaival kapcsolatban.",
    "Checking for system and security issues." : "Rendszer- és biztonsági problémák ellenőrzése.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Nézze meg még egyszer a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">telepítési dokumentációt ↗</a>, és keressen hibákat vagy figyelmeztetéseket a <a href=\"%2$s\">naplóban</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Ellenőrizze a Nextcloud biztonságát <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">a biztonsági ellenőrzéssel ↗</a>.",
    "Version" : "Verzió",
    "You need to enable the File sharing App." : "Engedélyeznie kell a Fájlmegosztás alkalmazást.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Rendszergazdaként finomhangolhatja a megosztás viselkedését. A részletekért lásd a dokumentációt.",
    "Allow apps to use the Share API" : "Engedélyezés, hogy az alkalmazások is használják a megosztási API-t",
    "Set default expiration date for shares" : "A megosztások alapértelmezett lejárati idejének beállítása",
    "Expire after" : "Lejárat ennyi idő után:",
    "day(s)" : "nap",
    "Enforce expiration date" : "Lejárati idő betartatása",
    "Set default expiration date for shares to other servers" : "A megosztás alapértelmezett lejárati idejének beállítása a többi kiszolgáló számára",
    "Allow users to share via link and emails" : "Hivatkozásokon és e-mailen keresztül megosztás engedélyezése a felhasználók számára",
    "Allow public uploads" : "Nyilvános feltöltés engedélyezése",
    "Always ask for a password" : "Mindig kérdezze meg a jelszót",
    "Enforce password protection" : "Hivatkozások jelszavas védelmének megkövetelése",
    "Exclude groups from password requirements:" : "Csoportok mentesítése a jelszókövetelmények alól:",
    "Set default expiration date" : "Alapértelmezett lejárati dátum beállítása",
    "Exclude groups from creating link shares:" : "Csoportok kizárása a megosztási hivatkozások létrehozásából:",
    "Allow resharing" : "Megosztás továbbosztásának engedélyezése",
    "Allow sharing with groups" : "Csoportokkal való megosztás engedélyezése",
    "Restrict users to only share with users in their groups" : "A felhasználók korlátozása, hogy csak a csoportjaikban lévő felhasználókkal oszthassanak meg dolgokat",
    "Exclude groups from sharing" : "Csoportok megosztási jogának tiltása",
    "These groups will still be able to receive shares, but not to initiate them." : "E csoportok tagjaival meg lehet osztani anyagokat, de ők nem hozhatnak létre megosztást.",
    "Allow username autocompletion in share dialog" : "A felhasználónév automatikus kiegészítésének engedélyezése a megosztás párbeszédpanelen ",
    "Allow username autocompletion to users within the same groups" : "A felhasználónév automatikus kiegészítésének engedélyezése az azonos csoportokba tartozó felhasználók számára ",
    "Allow username autocompletion to users based on phone number integration" : "A felhasználónév automatikus kiegészítésének engedélyezése a felhasználók számára a telefonszám integráció alapján ",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ha az „ugyanazon csoport” és a „telefonszám integráció” engedélyezett, akkor bármelyik egyezés elegendő a felhasználó megjelenítéséhez. ",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Az automatikus kiegészítés engedélyezése a teljes név vagy e-mail-cím megadásakor (figyelmen kívül hagyva a hiányzó telefonkönyves egyezést és az ugyanabba a csoportba tartozást)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Nyilatkozat szövegének megjelenítése a nyilvános feltöltési oldalon (csak akkor jelenik meg, ha fájllista rejtett)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ez a szöveg jelenik meg a nyilvános feltöltési oldalon, ha a fájllista rejtett.",
    "Default share permissions" : "Alapértelmezett megosztási jogosultságok",
    "Reasons to use Nextcloud in your organization" : "Miért használjon Nextcloudot a szervezeténél",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Fejleszti a {communityopen}Nextcloud közösség{linkclose}, a {githubopen}forráskódra{linkclose} az {licenseopen}AGPL{linkclose} licenc vonatkozik.",
    "Like our Facebook page" : "Kedvelje a Facebook oldalunkat",
    "Follow us on Twitter" : "Kövessen minket Twitteren",
    "Follow us on Mastodon" : "Kövessen minket a Mastodonon",
    "Check out our blog" : "Nézze meg a blogunkat",
    "Subscribe to our newsletter" : "Iratkozzon fel a hírlevelünkre",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "A Nextcloud e közösségi kiadása nem támogatott, és az azonnal értesítések nem érhetők el.",
    "Use a second factor besides your password to increase security for your account." : "Használjon egy második faktort a jelszava mellett, hogy növelje fiókja biztonságát.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ha harmadik féltől származó alkalmazásokat használ a Nextcloudhoz való csatlakozáshoz, akkor a két faktoros hitelesítés engedélyezése előtt győződjön meg róla, hogy mindegyikhez létrehozott és beállított egy alkalmazásjelszót.",
    "Migration in progress. Please wait until the migration is finished" : "Áttelepítés folyamatban. Kis türelmet, míg az áttelepítés befejeződik.",
    "Migration started …" : "Áttelepítés elindítva…",
    "An error occurred while changing your language. Please reload the page and try again." : "Hiba lépett fel nyelvváltás közben. Töltse újra az oldalt és próbálja meg újra.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Hiba a területi beállítás módosításakor. Töltse újra az oldalt, és próbálja meg újra.",
    "Select a profile picture" : "Válasszon profilképet",
    "Week starts on {fdow}" : "Hét kezdete: {fdow}",
    "Couldn't remove app." : "Az alkalmazás eltávolítása nem sikerült.",
    "Couldn't update app." : "Az alkalmazás frissítése nem sikerült.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "A háttérszolgáltatás nem támogatja a jelszómódosítást, de a felhasználó titkosítási kulcsa frissítve lett.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Nem sikerült megállapítani, hogy a cURL TLS-verziója elavult-e vagy sem, mert hiba történt a https://nextcloud.com felé küldött HTTPS-kérés során. További részletekért, ellenőrizze a Nextcloud naplófájlját.",
    "You need to set your user email before being able to send test emails." : "Előbb meg kell adnia az e-mail-címét, mielőtt tesztelni tudná az e-mail küldést.",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "A token visszavonása lehet hogy meggátolja az eszköz törlését, ha az még nem kezdődött el.",
    "Set as primary mail" : "Beállítás elsődleges e-mail-címként",
    "Change privacy level of email" : "Az e-mail-cím adatvédelmi szintjének módosítása",
    "All languages" : "Összes nyelv",
    "Everyone" : "Mindenki",
    "An error occured during the request. Unable to proceed." : "Hiba lépett fel a kérés közben. Nem lehet végrehajtani.",
    "Test email settings" : "E-mail beállítások ellenőrzése",
    "Please read carefully before activating server-side encryption: " : "Olvassa el figyelmesen, mielőtt bekapcsolja a kiszolgálóoldali titkosítást:",
    "Enable encryption" : "Titkosítás engedélyezése",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Át kell költöztetni a titkosítási kulcsokat a régi titkosításból (ownCloud <= 8.0) az újba. Engedélyezze az „Alapértelmezett titkosítási modult” és futtassa ezt: „occ encryption:migrate”",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Át kell költöztetni a titkosítási kulcsokat a régi titkosításból (ownCloud <= 8.0) az újba.",
    "Start migration" : "Átköltöztetés indítása",
    "Last job execution ran %s. Something seems wrong." : "Utolsó futás:%s. Valami nincs rendben.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Néhány feladat nem futott ezóta: %s. Fontolja meg a futási gyakoriság növelését. ",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Néhány feladat nem futott ezóta: %s. Fontolja meg a rendszer cronra váltást.",
    "Last job ran %s." : "Utolsó futás: %s.",
    "Background job didn’t run yet!" : "A háttérfeladat még nem futott le!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "A kiszolgáló helyes működéséhez fontos, hogy a háttérfeladatok megfelelően legyenek beállítva. A „Cron” beállítás javasolt. További részletekért lásd a dokumentációt.",
    "Pick background job setting" : "Háttérfolyamat beállítás kiválasztása",
    "Recommended" : "Ajánlott",
    "The cron.php needs to be executed by the system user \"%s\"." : "A cron.php-t „%s” rendszerfelhasználónak kell végrehajtania.",
    "days" : "nap",
    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "A felhasználónév automatikus kiegészítésének negedélyezése a teljes név vagy e-mail-cím megadásakor (figyelmen kívül hagyva a hiányzó telefonkönyves egyezést és az ugyanabba a csoportba tartozást)",
    "Change privacy level of profile picture" : "A profilkép adatvédelmi szintjének módosítása",
    "Upload new" : "Új feltöltése",
    "Select from Files" : "Kiválasztás a Fájlokból",
    "Remove image" : "Kép eltávolítása",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Vegye figyelembe, hogy akár 24 óráig is eltarthat, amíg a profilkép mindenhol frissül.",
    "Choose as profile picture" : "Kiválasztás profilképként",
    "You are using <strong>%s</strong>" : "Jelenleg használt: <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Jelenleg használt: <strong>%1$s</strong> / <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of full name" : "A teljes név adatvédelmi szintjének módosítása",
    "No display name set" : "Nincs megjelenítési név beállítva",
    "Change privacy level of phone number" : "A telefonszám adatvédelmi szintjének módosítása",
    "Address" : "Cím",
    "Change privacy level of address" : "A cím adatvédelmi szintjének módosítása",
    "Your postal address" : "A postai címe",
    "Change privacy level of website" : "A weboldal adatvédelmi szintjének módosítása",
    "It can take up to 24 hours before the account is displayed as verified." : "A fiók ellenőrzési folyamata, amíg láthatóvá válik, akár 24 óráig is eltarthat.",
    "Link https://…" : "https:// hivatkozás…",
    "Change privacy level of Twitter profile" : "A Twitter-profil adatvédelmi szintjének módosítása",
    "Twitter handle @…" : "Twitter azonosító @…",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Majdnem túllépte az OPcache kulcsok legnagyobb számát. Hogy biztosítsa, hogy az összes parancsfájl tárolható legyen a gyorsítótárban, ajánlatos, hogy a(z) <code>%s</code> értéknél nagyobbra állítsa az <code>opcache.max_accelerated_files</code> beállítást a PHP konfigurációjában.",
    "Admin privileges" : "Rendszergazdai jogosultságok",
    "Unable to update biography" : "Az életrajt nem frissíthető",
    "Unable to update full name" : "A teljes név nem frissíthető",
    "No full name set" : "Nincs teljes név megadva",
    "Unable to update headline" : "A címsor nem frissíthető",
    "Unable to update organisation" : "A szervezet nem frissíthető",
    "Unable to update role" : "A szerepkör nem frissíthető",
    "Change scope level of {accountProperty}" : "A(z) {accountProperty} hatókörszintjének módosítása",
    "Unable to update federation scope of the primary {accountProperty}" : "Az elsődleges {accountProperty} föderációs hatóköre nem frissíthető",
    "Unable to update federation scope of additional {accountProperty}" : "A további {accountProperty} föderációs hatóköre nem frissíthető",
    "Avatar" : "Profilkép"
},
"nplurals=2; plural=(n != 1);");
